"""
GUI to view the types of plotting and their descriptions
NOTE: plot's types are defined in __init__.plot_functions
"""

from sohstationviewer.view.util.plot_func_names import plot_functions
from sohstationviewer.view.db_config.db_config_dialog import UiDBInfoDialog


class PlotTypeDialog(UiDBInfoDialog):
    def __init__(self, parent):
        super().__init__(
            parent, ['No.', '       Plot Type        ', 'Description'],
            '', '', resize_content_columns=[0, 1], check_fk=False)
        self.setWindowTitle("Plotting Types")

    def add_row(self, row_idx, fk=False):
        """
        Add a row of widgets to self.data_table_widgets.

        :param row_idx: index of row to add
        :param fk: bool: There isn't a foreign constrain in this table but
            plot's types are based on plotting functions which are hard code
            so it's needed to set to True to prevent the row to be deleted
        """
        self.add_widget(None, row_idx, 0)       # No.
        self.add_widget(self.data_list, row_idx, 1, foreign_key=True)
        self.add_widget(self.data_list, row_idx, 2, foreign_key=True,
                        field_name='description')

    def get_data_list(self):
        """
        Get list of data to fill self.data_table_widgets' content
        """
        return [[key, val[0]] for key, val in plot_functions.items()]
